Crate snops_checkpoint

Crate snops_checkpoint 

Modules

errors

Structs

CheckpointHeader
CheckpointManager
RetentionPolicy
A comma separated list of retention rules ordered by duration, with the first rule being the shortest
RetentionRule
An individual rule in a retention policy

Enums

RetentionSpan

Functions

path_from_height