pub struct CheckpointManager { /* private fields */ }Implementations
Sourceimpl CheckpointManager
impl CheckpointManager
Sourcepub fn load(
storage_path: PathBuf,
policy: RetentionPolicy,
) -> Result<Self, ManagerLoadError>
pub fn load( storage_path: PathBuf, policy: RetentionPolicy, ) -> Result<Self, ManagerLoadError>
Given a storage path, load headers from the available checkpoints into memory
Sourcepub fn is_ready(&self, timestamp: &DateTime<Utc>) -> bool
pub fn is_ready(&self, timestamp: &DateTime<Utc>) -> bool
Check if the manager is ready to create a new checkpoint given the current timestamp
pub fn cull(&mut self)
Sourcepub fn cull_timestamp(&mut self, timestamp: DateTime<Utc>)
pub fn cull_timestamp(&mut self, timestamp: DateTime<Utc>)
Remove the oldest checkpoints that are no longer needed
Sourcepub fn policy(&self) -> &RetentionPolicy
pub fn policy(&self) -> &RetentionPolicy
Get the retention policy used by this manager
Sourcepub fn checkpoints(&self) -> impl Iterator<Item = &(CheckpointHeader, PathBuf)>
pub fn checkpoints(&self) -> impl Iterator<Item = &(CheckpointHeader, PathBuf)>
Iterate the checkpoints stored by this manager