RetentionPolicy

Struct RetentionPolicy 

pub struct RetentionPolicy {
    pub rules: Vec<RetentionRule>,
}
A comma separated list of retention rules ordered by duration, with the first rule being the shortest

eg. 4h:1h,1W:U,4W:1D,6M:1W,1Y:1M,U:6M

Fields

rules: Vec<RetentionRule>

Implementations

Source

impl RetentionPolicy

pub fn new(rules: Vec<RetentionRule>) -> Self

pub fn is_ready_with_time( &self, new_time: &DateTime<Utc>, last_time: &DateTime<Utc>, ) -> bool

Returns true if the policy is ready to be applied based on a given time

pub fn reject(&self, times: Vec<&DateTime<Utc>>) -> Vec<DateTime<Utc>>

Receives a list of checkpoint times, and returns a list of times to reject

pub fn reject_with_time( &self, now: DateTime<Utc>, times: Vec<&DateTime<Utc>>, ) -> Vec<DateTime<Utc>>

Receives a list of checkpoint times, and returns a list of times to reject given a time