snops_
checkpoint
0.1.0
All Items
Crate Items
Modules
Structs
Enums
Functions
Crate
snops_checkpoint
Modules

errors
Structs

Checkpoint
Header
Checkpoint
Manager
Retention
Policy
A comma separated list of retention rules ordered by duration, with the first rule being the shortest
Retention
Rule
An individual rule in a retention policy
Enums

Retention
Span
Functions

path_
from_
height