pub struct RetentionPolicy {
pub rules: Vec<RetentionRule>,
}Expand description
A comma separated list of retention rules ordered by duration, with the first rule being the shortest
eg. 4h:1h,1W:U,4W:1D,6M:1W,1Y:1M,U:6M
Fields
rules: Vec<RetentionRule>Implementations
Sourceimpl RetentionPolicy
impl RetentionPolicy
pub fn new(rules: Vec<RetentionRule>) -> Self
Sourcepub fn is_ready_with_time(
&self,
new_time: &DateTime<Utc>,
last_time: &DateTime<Utc>,
) -> bool
pub fn is_ready_with_time( &self, new_time: &DateTime<Utc>, last_time: &DateTime<Utc>, ) -> bool
Returns true if the policy is ready to be applied based on a given time